@@ -1,7 +1,6 @@
 from pylytics.library.dim import Dim
-import settings
 
 
 class DimLocation(Dim):
-    source_db = settings.pylytics_db
+    source_db = "test"  # A database defined in settings.py
     source_query = "SELECT DISTINCT `location_name` FROM `sales`"
