@@ -11,17 +11,3 @@ CREATE TABLE `fact_count_all_the_sales` (
   CONSTRAINT `fact_count_all_the_sales_ibfk_2` FOREIGN KEY (`dim_location`) REFERENCES `dim_location` (`id`),
   CONSTRAINT UQ_date_location UNIQUE (`dim_date`, `dim_location`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
-
-# Creating a view is optional.
-CREATE VIEW `view_fact_count_all_the_sales` AS (
-  SELECT
-    dd.date AS `date`,
-    f.fact_count AS `count`,
-    l.location AS location
-  FROM
-    fact_count_all_the_sales f
-  JOIN
-    dim_date dd ON f.dim_date = dd.id
-  JOIN
-    dim_location l ON f.dim_location = l.id
-);
