@@ -1,4 +1,5 @@
 import datetime
+import inspect
 import warnings
 
 from build_sql import SQLBuilder
@@ -16,6 +17,8 @@ class Fact(Table):
     """
     
     historical_iterations = 100
+    setup_scripts = {}
+    exit_scripts = {}
     
     def __init__(self, *args, **kwargs):
         self.dim_or_fact = 'fact'
@@ -281,7 +284,15 @@ class Fact(Table):
 
         """
         self.update()
-        
+
         for i in xrange(1, self.historical_iterations):
             self._process_data(historical=True, index=i)
             self._insert_rows()
+
+    @classmethod
+    def public_methods(self):
+        """
+        Returns a list of all public method names on this class.
+        """
+        methods = inspect.getmembers(self, predicate=inspect.ismethod)
+        return [i[0] for i in methods if not i[0].startswith('_')]
